mod thread_local_bump_allocator;

pub mod string_utils;

pub(crate) use thread_local_bump_allocator::*;
